@@ -3,7 +3,7 @@ from simframe.integration.scheme import Scheme
 import numpy as np
 
 
-def _f_impl_1_euler_direct(x0, Y0, dx, *args, **kwargs):
+def _f_impl_1_euler_direct(x0, Y0, dx, jac=None, *args, **kwargs):
     """Implicit 1st-order Euler integration scheme with direct matrix inversion
 
     Parameters
@@ -14,6 +14,8 @@ def _f_impl_1_euler_direct(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    jac : Field, optional, defaul : None
+        Current Jacobian. Will be calculated, if not set
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -28,11 +30,12 @@ def _f_impl_1_euler_direct(x0, Y0, dx, *args, **kwargs):
     ---|---
        | 1 
     """
-    jac = Y0.jacobian(x0 + dx)
+    if jac is None:
+        jac = Y0.jacobian(x0 + dx)
     N = jac.shape[0]
     eye = np.eye(N)
-    A = eye - dx*jac
-    return np.dot(np.linalg.inv(A), Y0)
+    A = eye - dx[0] * jac
+    return (np.linalg.inv(A) - eye) @ Y0
 
 
 impl_1_euler_direct = Scheme(
